import os, os.path
from Globals import package_home

from Products.Archetypes.public import process_types, listTypes
from Products.CMFCore import utils
from Products.CMFCore.DirectoryView import registerDirectory
from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.GenericSetup import EXTENSION, profile_registry

#import isodatevalidator

from config import SKINS_DIR, GLOBALS, PROJECTNAME
from config import ADD_CONTENT_PERMISSION

# Import "PloneSurveyMessageFactory as _" to create messages in plonesurvey domain
from zope.i18nmessageid import MessageFactory
PloneSurveyMessageFactory = MessageFactory('plonesurvey')

registerDirectory(SKINS_DIR, GLOBALS)

def initialize(context):
    import Products.PloneSurvey.content

    content_types, constructors, ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    utils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = content_types,
        permission         = ADD_CONTENT_PERMISSION,
        extra_constructors = constructors,
        fti                = ftis,
        ).initialize(context)
